==> hs-hxt-8.5.2_1.tbz: lib/hxt-8.5.2/register.sh <==
#!/bin/sh

echo 'name: hxt
version: 8.5.2
license: OtherLicense
copyright: Copyright (c) 2005-2010 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: stable
homepage: http://www.fh-wedel.de/~si/HXmlToolbox/index.html
package-url:
description: The Haskell XML Toolbox bases on the ideas of HaXml and HXML, but introduces a more general approach for processing XML with Haskell. The Haskell XML Toolbox uses a generic data model for representing XML documents, including the DTD subset and the document subset, in Haskell. It contains a validating XML parser, a HTML parser, namespace support, an XPath expression evaluator, an XSLT library, a RelaxNG schema validator and funtions for serialization and deserialization of user defined data. The library make extensive use of the arrow approach for processing XML. Since version 8.5 XPath and XSLT have been moved to separate packages hxt-xpath and hxt-xslt.
category: XML
author:
exposed: True
exposed-modules: Control.Arrow.ArrowIO Control.Arrow.ArrowIf
                 Control.Arrow.ArrowList Control.Arrow.ArrowNF
                 Control.Arrow.ArrowState Control.Arrow.ArrowTree
                 Control.Arrow.IOListArrow Control.Arrow.IOStateListArrow
                 Control.Arrow.ListArrow Control.Arrow.ListArrows
                 Control.Arrow.StateListArrow Data.AssocList Data.Atom
                 Data.Char.UTF8 Data.Tree.Class Data.Tree.NTree.TypeDefs
                 Text.XML.HXT.Arrow Text.XML.HXT.Arrow.DTDProcessing
                 Text.XML.HXT.Arrow.DocumentInput Text.XML.HXT.Arrow.DocumentOutput
                 Text.XML.HXT.Arrow.Edit
                 Text.XML.HXT.Arrow.GeneralEntitySubstitution
                 Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
                 Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
                 Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
                 Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
                 Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
                 Text.XML.HXT.Arrow.XmlIOStateArrow Text.XML.HXT.Arrow.XmlRegex
                 Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
                 Text.XML.HXT.DOM.IsoLatinTables Text.XML.HXT.DOM.MimeTypeDefaults
                 Text.XML.HXT.DOM.MimeTypes Text.XML.HXT.DOM.QualifiedName
                 Text.XML.HXT.DOM.ShowXml Text.XML.HXT.DOM.TypeDefs
                 Text.XML.HXT.DOM.UTF8Decoding Text.XML.HXT.DOM.Unicode
                 Text.XML.HXT.DOM.Util Text.XML.HXT.DOM.XmlKeywords
                 Text.XML.HXT.DOM.XmlNode Text.XML.HXT.DOM.XmlOptions
                 Text.XML.HXT.DTDValidation.AttributeValueValidation
                 Text.XML.HXT.DTDValidation.DTDValidation
                 Text.XML.HXT.DTDValidation.DocTransformation
                 Text.XML.HXT.DTDValidation.DocValidation
                 Text.XML.HXT.DTDValidation.IdValidation
                 Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
                 Text.XML.HXT.DTDValidation.Validation
                 Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
                 Text.XML.HXT.IO.GetHTTPLibCurl Text.XML.HXT.Parser.HtmlParsec
                 Text.XML.HXT.Parser.ProtocolHandlerUtil Text.XML.HXT.Parser.TagSoup
                 Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
                 Text.XML.HXT.Parser.XmlDTDParser
                 Text.XML.HXT.Parser.XmlDTDTokenParser
                 Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
                 Text.XML.HXT.Parser.XmlTokenParser Text.XML.HXT.RelaxNG
                 Text.XML.HXT.RelaxNG.BasicArrows Text.XML.HXT.RelaxNG.CreatePattern
                 Text.XML.HXT.RelaxNG.DataTypeLibMysql
                 Text.XML.HXT.RelaxNG.DataTypeLibUtils
                 Text.XML.HXT.RelaxNG.DataTypeLibraries
                 Text.XML.HXT.RelaxNG.DataTypes
                 Text.XML.HXT.RelaxNG.PatternFunctions
                 Text.XML.HXT.RelaxNG.PatternToString Text.XML.HXT.RelaxNG.Schema
                 Text.XML.HXT.RelaxNG.SchemaGrammar
                 Text.XML.HXT.RelaxNG.Simplification
                 Text.XML.HXT.RelaxNG.Unicode.Blocks
                 Text.XML.HXT.RelaxNG.Unicode.CharProps Text.XML.HXT.RelaxNG.Utils
                 Text.XML.HXT.RelaxNG.Validation Text.XML.HXT.RelaxNG.Validator
                 Text.XML.HXT.RelaxNG.XmlSchema.DataTypeLibW3C
                 Text.XML.HXT.RelaxNG.XmlSchema.Regex
                 Text.XML.HXT.RelaxNG.XmlSchema.RegexMatch
                 Text.XML.HXT.RelaxNG.XmlSchema.RegexParser Text.XML.HXT.Version
hidden-modules:
import-dirs: /usr/local/lib/hxt-8.5.2/ghc-6.10.4
library-dirs: /usr/local/lib/hxt-8.5.2/ghc-6.10.4 /usr/local/lib
hs-libraries: HShxt-8.5.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.0.3 base-4.1.0.0 bytestring-0.9.1.4
         containers-0.2.0.1 curl-1.3.5 deepseq-1.1.0.0 directory-1.0.0.3
         filepath-1.1.0.2 haskell98-1.0.1.0 network-2.2.1.2 parsec-2.1.0.1
         tagsoup-0.10
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hxt-8.5.2/html/hxt.haddock
haddock-html: /usr/local/share/doc/hxt-8.5.2/html' | /usr/local/bin/ghc-pkg update -

==> hs-hxt-8.5.4.tbz: lib/hxt-8.5.4/register.sh <==
#!/bin/sh

echo 'name: hxt
version: 8.5.4
license: OtherLicense
copyright: Copyright (c) 2005-2010 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: http://www.fh-wedel.de/~si/HXmlToolbox/index.html
package-url:
description: The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
             but introduces a more general approach for processing XML with Haskell.
             The Haskell XML Toolbox uses a generic data model for representing XML documents,
             including the DTD subset and the document subset, in Haskell.
             It contains a validating XML parser, a HTML parser, namespace support,
             an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
             and funtions for serialization and deserialization of user defined data.
             The library makes extensive use of the arrow approach for processing XML.
             Since version 8.5 XPath and XSLT have been moved to separate packages hxt-xpath and hxt-xslt,
             serialisation is in package hxt-binary
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
exposed-modules: Control.Arrow.ArrowIO Control.Arrow.ArrowIf
                 Control.Arrow.ArrowList Control.Arrow.ArrowNF
                 Control.Arrow.ArrowState Control.Arrow.ArrowTree
                 Control.Arrow.IOListArrow Control.Arrow.IOStateListArrow
                 Control.Arrow.ListArrow Control.Arrow.ListArrows
                 Control.Arrow.StateListArrow Data.AssocList Data.Atom
                 Data.Char.UTF8 Data.Tree.Class Data.Tree.NTree.TypeDefs
                 Text.XML.HXT.Arrow Text.XML.HXT.Arrow.DTDProcessing
                 Text.XML.HXT.Arrow.DocumentInput Text.XML.HXT.Arrow.DocumentOutput
                 Text.XML.HXT.Arrow.Edit
                 Text.XML.HXT.Arrow.GeneralEntitySubstitution
                 Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
                 Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
                 Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
                 Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
                 Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
                 Text.XML.HXT.Arrow.XmlIOStateArrow Text.XML.HXT.Arrow.XmlRegex
                 Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
                 Text.XML.HXT.DOM.IsoLatinTables Text.XML.HXT.DOM.MimeTypeDefaults
                 Text.XML.HXT.DOM.MimeTypes Text.XML.HXT.DOM.QualifiedName
                 Text.XML.HXT.DOM.ShowXml Text.XML.HXT.DOM.TypeDefs
                 Text.XML.HXT.DOM.UTF8Decoding Text.XML.HXT.DOM.Unicode
                 Text.XML.HXT.DOM.Util Text.XML.HXT.DOM.XmlKeywords
                 Text.XML.HXT.DOM.XmlNode Text.XML.HXT.DOM.XmlOptions
                 Text.XML.HXT.DTDValidation.AttributeValueValidation
                 Text.XML.HXT.DTDValidation.DTDValidation
                 Text.XML.HXT.DTDValidation.DocTransformation
                 Text.XML.HXT.DTDValidation.DocValidation
                 Text.XML.HXT.DTDValidation.IdValidation
                 Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
                 Text.XML.HXT.DTDValidation.Validation
                 Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
                 Text.XML.HXT.IO.GetHTTPLibCurl Text.XML.HXT.Parser.HtmlParsec
                 Text.XML.HXT.Parser.ProtocolHandlerUtil Text.XML.HXT.Parser.TagSoup
                 Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
                 Text.XML.HXT.Parser.XmlDTDParser
                 Text.XML.HXT.Parser.XmlDTDTokenParser
                 Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
                 Text.XML.HXT.Parser.XmlTokenParser Text.XML.HXT.RelaxNG
                 Text.XML.HXT.RelaxNG.BasicArrows Text.XML.HXT.RelaxNG.CreatePattern
                 Text.XML.HXT.RelaxNG.DataTypeLibMysql
                 Text.XML.HXT.RelaxNG.DataTypeLibUtils
                 Text.XML.HXT.RelaxNG.DataTypeLibraries
                 Text.XML.HXT.RelaxNG.DataTypes
                 Text.XML.HXT.RelaxNG.PatternFunctions
                 Text.XML.HXT.RelaxNG.PatternToString Text.XML.HXT.RelaxNG.Schema
                 Text.XML.HXT.RelaxNG.SchemaGrammar
                 Text.XML.HXT.RelaxNG.Simplification
                 Text.XML.HXT.RelaxNG.Unicode.Blocks
                 Text.XML.HXT.RelaxNG.Unicode.CharProps Text.XML.HXT.RelaxNG.Utils
                 Text.XML.HXT.RelaxNG.Validation Text.XML.HXT.RelaxNG.Validator
                 Text.XML.HXT.RelaxNG.XmlSchema.DataTypeLibW3C
                 Text.XML.HXT.RelaxNG.XmlSchema.Regex
                 Text.XML.HXT.RelaxNG.XmlSchema.RegexMatch
                 Text.XML.HXT.RelaxNG.XmlSchema.RegexParser Text.XML.HXT.Version
hidden-modules:
import-dirs: /usr/local/lib/hxt-8.5.4/ghc-6.10.4
library-dirs: /usr/local/lib/hxt-8.5.4/ghc-6.10.4 /usr/local/lib
hs-libraries: HShxt-8.5.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.0.3 base-4.1.0.0 bytestring-0.9.1.4
         containers-0.2.0.1 curl-1.3.5 deepseq-1.1.0.0 directory-1.0.0.3
         filepath-1.1.0.2 haskell98-1.0.1.0 network-2.2.1.2 parsec-2.1.0.1
         tagsoup-0.10.1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hxt-8.5.4/html/hxt.haddock
haddock-html: /usr/local/share/doc/hxt-8.5.4/html' | /usr/local/bin/ghc-pkg update -
